@@ -2,8 +2,7 @@ from django import template
 from django.http import Http404
 from django.utils.translation import gettext_lazy as _
 
-from .. import common
-from ..settings import INVALID_FIELD_RAISES_404
+from .. import common, settings
 
 register = template.Library()
 
@@ -77,15 +76,22 @@ def autosort(parser, token):
     )
     context_var = None
 
-    # Check if has not required "as new_context_var" part
-    if len(bits) == 4 and bits[2] == "as":
-        context_var = bits[3]
-        del bits[2:]
-
-    if len(bits) != 2:
+    # Check if their is some optional parameter (as new_context_var, nulls)
+    if 2 > len(bits) > 7:
         raise template.TemplateSyntaxError(help_msg)
 
-    return SortedDataNode(bits[1], context_var=context_var)
+    context_var = None
+    null_ordering = None
+
+    for index, bit in enumerate(bits):
+        if index > 1:
+            if bit == "as" and index + 1 < len(bits):
+                context_var = bits[index + 1]
+                del bits[index : index + 1]
+            if bit.startswith("nulls"):
+                null_ordering = bit[len("nulls=") :]
+
+    return SortedDataNode(bits[1], null_ordering, context_var=context_var)
 
 
 class SortedDataNode(template.Node):
@@ -93,9 +99,10 @@ class SortedDataNode(template.Node):
     Automatically sort a queryset with {% autosort queryset %}
     """
 
-    def __init__(self, queryset_var, context_var=None):
+    def __init__(self, queryset_var, null_ordering, context_var=None):
         self.queryset_var = template.Variable(queryset_var)
         self.context_var = context_var
+        self.null_ordering = null_ordering
 
     def render(self, context):
         if self.context_var is not None:
@@ -105,13 +112,14 @@ class SortedDataNode(template.Node):
 
         queryset = self.queryset_var.resolve(context)
         order_by = common.get_order_by_from_request(context["request"])
+        null_ordering = common.get_null_ordering(context["request"], self.null_ordering)
 
         try:
-            context[key] = common.sort_queryset(queryset, order_by)
+            context[key] = common.sort_queryset(queryset, order_by, null_ordering)
         except ValueError as e:
             raise template.TemplateSyntaxError from e
         except AttributeError:
-            if INVALID_FIELD_RAISES_404:
+            if settings.INVALID_FIELD_RAISES_404:
                 raise Http404(
                     "Invalid field sorting. If INVALID_FIELD_RAISES_404 were set to "
                     "False, the error would have been ignored."
